Spelling Correction
==========================

.. note::

    This tutorial is available as an IPython notebook
    `here <https://github.com/huseinzol05/Malaya/tree/master/example/spell-correction>`_.

.. include:: load-spell-correction.rst
